@@ -2,4 +2,6 @@ from .djangoPubSub import DjangoPubSub
 from .handler import Handler
 from kfpubsub import on_event
 
-PubSub = DjangoPubSub()
+from .lazy_pub_sub import LazyPubSub
+
+PubSub = LazyPubSub()
